@@ -1,3 +1,5 @@
+# encoding=utf8  
+from .udpipe_parser_temp import *
 from .text_preprocessor import TextPreProcessor
 from .dicts import *
 from .utilities import *
